@@ -80,7 +80,7 @@ def create_in_existing_vpc(cluster):
     cluster.head_node = _create_head_node(
         cluster.vpc, head_node_hostname, head_node_subnet, cluster.head_node_image, head_node_sg_id, node_sg_id)
 
-    _retry_not_found(_disable_source_dest_check(cluster.head_node))
+    _retry_not_found(_disable_source_dest_check, cluster.head_node)
 
     _report_progress(22, "Done setting up VPC for %s" % cluster.name)
 
@@ -124,7 +124,7 @@ def create_vpc(cluster):
     cluster.head_node = _create_head_node(
         cluster.vpc, head_node_hostname, public_subnet, cluster.head_node_image, head_node_sg_id, node_sg_id)
 
-    _retry_not_found(_disable_source_dest_check(cluster.head_node))
+    _retry_not_found(_disable_source_dest_check, cluster.head_node)
 
     log.info("Waiting for head node to be running")
     cluster.head_node.wait_until_running()  # must be running for being usable as gateway
@@ -133,16 +133,16 @@ def create_vpc(cluster):
     _report_progress(22, "Done setting up VPC for %s" % vpc_name)
 
 
-def _retry_not_found(func):
-    # Retry NotFound-like exceptions
-    retry_wrapper = tenacity.retry(
+def _retry_not_found(func, *args, **kwargs):
+    retry_wrapper = tenacity.Retrying(
         retry=tenacity.retry_if_exception_message(match=".*NotFound.*"),
-        wait=tenacity.wait_exponential(multiplier=1, max=100),
-        stop=tenacity.stop_after_attempt(10),
+        wait=tenacity.wait_exponential(multiplier=1, max=60),
+        stop=tenacity.stop_after_delay(300),
         before_sleep=tenacity.before_sleep_log(log, logging.DEBUG),
+        after=tenacity.after_log(log, logging.DEBUG),
         reraise=True,
     )
-    return retry_wrapper(func)
+    return retry_wrapper(func, *args, **kwargs)
 
 
 def _create_vpc(vpc_name, ec2):
@@ -152,7 +152,7 @@ def _create_vpc(vpc_name, ec2):
     # Make sure the VPC has finished creation before setting tags on it.
     # See https://docs.aws.amazon.com/AWSEC2/latest/APIReference/query-api-troubleshooting.html#eventual-consistency
     vpc.wait_until_exists()
-    _retry_not_found(vpc.wait_until_available)()
+    _retry_not_found(vpc.wait_until_available)
     log.debug("VPC was successfully created, id: %s", vpc.id)
 
     return vpc
@@ -213,9 +213,10 @@ def _set_default_gateway_vpc(vpc, internet_gateway):
 # we set the gateway, we can still encounter incorrect instance state errors.
 @tenacity.retry(
     retry=tenacity.retry_if_exception_message(match=".*IncorrectInstanceState.*"),
-    wait=tenacity.wait_exponential(multiplier=1, max=100),
-    stop=tenacity.stop_after_delay(500),
+    wait=tenacity.wait_exponential(multiplier=1, max=60),
+    stop=tenacity.stop_after_delay(300),
     before_sleep=tenacity.before_sleep_log(log, logging.DEBUG),
+    after=tenacity.after_log(log, logging.DEBUG),
     reraise=True
 )
 def _set_default_gateway_subnet(vpc, subnet, internet_gateway):
@@ -349,7 +350,7 @@ def _create_head_node(vpc, hostname, public_subnet, head_node_image, head_node_s
     log.info(f"Created VM {head_node_instance.id}")
 
     log.debug("Waiting for VM to exist so that we can assign tags")
-    _retry_not_found(head_node_instance.wait_until_exists)()
+    _retry_not_found(head_node_instance.wait_until_exists)
 
     log.debug("Applying tags to the head node VM instance")
     head_node_instance.name = f"{vpc.cluster_name} (Bright COD-AWS {config['version']} head node)"
@@ -450,11 +451,9 @@ def _create_tags(vpc, obj, bcm_type=None):
     if bcm_type:
         tags["BCM Type"] = bcm_type
 
-    tags.update(dict((str(k), str(v))
-                     for k, v in config["cluster_tags"]))
-
-    res = _retry_not_found(obj.create_tags)(Tags=[{"Key": key, "Value": value}
-                                            for key, value in six.iteritems(tags)])
+    tags.update(dict((str(k), str(v)) for k, v in config["cluster_tags"]))
+    tags = [{"Key": key, "Value": value} for key, value in six.iteritems(tags)]
+    res = _retry_not_found(obj.create_tags, Tags=tags)
     log.debug("create tag response: %s", res)
 
 
